<template>
  <div class="Checkbox" :class="variant" :hidden="hidden">
    <input
      :id="`${name}--checkbox`"
      type="checkbox"
      :name="name"
      :checked="value"
      :style="{ display: 'none' }"
      @change="$emit('input', $event.target.checked)"
    />
    <label :for="`${name}--checkbox`">
      <span class="label-inner">
        <slot />
      </span>
    </label>
  </div>
</template>

<script>
export default {
  name: 'Checkbox',
  props: {
    name: {
      type: String,
      default: ''
    },
    value: {
      type: Boolean,
      default: false
    },
    variant: {
      type: String,
      default: 'normal'
    },
    hidden: {
      type: Boolean,
      default: false
    }
  }
}
</script>

<style scoped lang="sass">
.Checkbox[hidden]
  display: none
.Checkbox:not([hidden])
  display: flex
  align-items: center
.Checkbox.normal
  label::before
    content: ''
    width: 1.2em
    height: 1.2em
    border: 2px solid var(--primary)
    border-radius: 5px
    display: inline-block
    margin-right: 0.5em
  input:checked + label::before
    background: var(--primary)
  label
    display: flex
    align-items: center
    cursor: pointer
</style>
